@@ -19,7 +19,16 @@ class Database:
         self.cursor = self.connection.cursor()
 
         self.cursor.execute(
-            "CREATE TABLE IF NOT EXISTS equations ("
+            "CREATE TABLE IF NOT EXISTS inline ("
+            "  hash TEXT PRIMARY KEY CHECK (length(hash) == 64), "
+            "  equation TEXT UNIQUE, "
+            "  rendered TEXT, "
+            "  settings TEXT"
+            ")"
+        )
+
+        self.cursor.execute(
+            "CREATE TABLE IF NOT EXISTS display ("
             "  hash TEXT PRIMARY KEY CHECK (length(hash) == 64), "
             "  equation TEXT UNIQUE, "
             "  rendered TEXT, "
@@ -30,22 +39,36 @@ class Database:
 
     def add_equation(
         self,
+        inline: bool,
         equation: str,
         settings: PelicanMathSettings,
         rendered: str | None = None,
     ):
         hash = hash_equation(equation)
-        self.cursor.execute(
-            "INSERT OR REPLACE INTO equations VALUES (?, ?, ?, ?)",
-            (hash, equation, rendered, settings.serialize()),
-        )
+        if inline:
+            self.cursor.execute(
+                "INSERT OR REPLACE INTO inline VALUES (?, ?, ?, ?)",
+                (hash, equation, rendered, settings.serialize()),
+            )
+        else:
+            self.cursor.execute(
+                "INSERT OR REPLACE INTO display VALUES (?, ?, ?, ?)",
+                (hash, equation, rendered, settings.serialize()),
+            )
         self.connection.commit()
 
-    def fetch_rendered_equation(self, equation: str) -> tuple[str | None, str | None]:
+    def fetch_rendered_equation(
+        self, inline: bool, equation: str
+    ) -> tuple[str | None, str | None]:
         hash = hash_equation(equation)
-        self.cursor.execute(
-            "SELECT rendered, settings FROM equations WHERE hash = ?", (hash,)
-        )
+        if inline:
+            self.cursor.execute(
+                "SELECT rendered, settings FROM inline WHERE hash = ?", (hash,)
+            )
+        else:
+            self.cursor.execute(
+                "SELECT rendered, settings FROM display WHERE hash = ?", (hash,)
+            )
         entry = self.cursor.fetchone()
         self.connection.commit()
         if entry:
@@ -53,6 +76,10 @@ class Database:
 
         return None, None
 
-    def fetch_missing_equations(self) -> list[str]:
-        self.cursor.execute("SELECT equation FROM equations WHERE rendered IS NULL")
+    def fetch_missing_inline(self) -> list[str]:
+        self.cursor.execute("SELECT equation FROM inline WHERE rendered IS NULL")
+        return [entry[0] for entry in self.cursor.fetchall()]
+
+    def fetch_missing_display(self) -> list[str]:
+        self.cursor.execute("SELECT equation FROM display WHERE rendered IS NULL")
         return [entry[0] for entry in self.cursor.fetchall()]
