@@ -1,11 +1,14 @@
+from pelican import Pelican
 import pelican.plugins.signals
 
 from .extension import PelicanMathExtension
+from .settings import PelicanMathSettings
 
 
-def init_math(sender):
+def init_math(sender: Pelican):
+    settings = PelicanMathSettings.from_settings(sender)
     sender.settings["MARKDOWN"].setdefault("extensions", []).append(
-        PelicanMathExtension()
+        PelicanMathExtension(settings)
     )
 
 
